# Andreani Advanced Analytics tools

### Listado de funciones agregadas:

* Distancia euclidia entre dos puntos.

* logger


### Listado de funciones a agregar:

* División de un dataframe en una lista de dataframes para procesamiento en hilos.

* Conexión al datalake.

* Logger

* Distancia de ruta entre dos puntos.

* Model training
